@@ -15,6 +15,7 @@ import numpy as np
 import scipy
 import skimage.draw
 import scipy.interpolate
+import scipy.signal as ss
 import soundfile
 from dataclasses import dataclass
 from typing import Callable
@@ -194,6 +195,11 @@ class MainWindow(pg.QtGui.QMainWindow):
                                     event_names=event_names,
                                     event_categories=event_classes)
 
+                if form_data['filter_song'] == 'yes':
+                    f_low = eval(form_data['f_low'])
+                    f_high = eval(form_data['f_high'])
+                    ds = cls.filter_song(ds, f_low, f_high)
+
                 fmin = float(dialog.form['spec_freq_min']) if len(dialog.form['spec_freq_min']) else None
                 fmax = float(dialog.form['spec_freq_max']) if len(dialog.form['spec_freq_max']) else None
 
@@ -246,6 +252,12 @@ class MainWindow(pg.QtGui.QMainWindow):
                                 keep_multi_channel=True,
                                 target_sampling_rate=form_data['target_samplingrate'],
                                 resample_video_data=resample_video_data)
+
+                if form_data['filter_song'] == 'yes':
+                    f_low = eval(form_data['f_low'])
+                    f_high = eval(form_data['f_high'])
+                    ds = cls.filter_song(ds, f_low, f_high)
+
                 if form_data['init_annotations'] and len(form_data['events_string']):
                     # parse events_string
                     event_types = []
@@ -335,6 +347,11 @@ class MainWindow(pg.QtGui.QMainWindow):
                     if 'song_raw' in ds:  # this will take a long time:
                         ds.song_raw.load()  # non-lazy load song for faster updates
 
+                if form_data['filter_song'] == 'yes':
+                    f_low = eval(form_data['f_low'])
+                    f_high = eval(form_data['f_high'])
+                    ds = cls.filter_song(ds, f_low, f_high)
+
                 # add event categories if they are missing in the dataset
                 if 'song_events' in ds and 'event_categories' not in ds:
                     event_categories = ['segment'
@@ -367,6 +384,24 @@ class MainWindow(pg.QtGui.QMainWindow):
                 return PSV(ds, vr=vr, cue_points=cue_points, title=filename,
                         fmin=fmin, fmax=fmax, box_size=box_size, data_source=DataSource('zarr', filename))
 
+    @classmethod
+    def filter_song(cls, ds, f_low, f_high):
+        if 'song_raw' in ds:  # this will take a long time:
+            if f_high is None:
+                f_high = ds.song_raw.attrs['sampling_rate_Hz'] / 2 - 1
+            logging.info(f'Filtering `song_raw` between {f_low} and {f_high} Hz.')
+            sos_bp = ss.butter(5, [f_low, f_high], 'bandpass', output='sos',
+                                fs=ds.song_raw.attrs['sampling_rate_Hz'])
+            ds.song_raw.data = ss.sosfiltfilt(sos_bp, ds.song_raw.data, axis=0)
+        if 'song' in ds:
+            if f_high is None:
+                f_high = ds.song.attrs['sampling_rate_Hz'] / 2 - 1
+            logging.info(f'Filtering `song` between {f_low} and {f_high} Hz.')
+            sos_bp = ss.butter(5, [f_low, f_high], 'bandpass', output='sos',
+                                fs=ds.song.attrs['sampling_rate_Hz'])
+            ds.song.data = ss.sosfiltfilt(sos_bp, ds.song.data, axis=0)
+        return ds
+
     @classmethod
     def from_npydir(cls, dirname=None, app=None, qt_keycode=None):
         logging.info('Not implemented yet')
@@ -520,9 +555,9 @@ class PSV(MainWindow):
         self.nb_channels = None
         if 'song' in self.ds:
             self.fs_song = self.ds.song.attrs['sampling_rate_Hz']
-        elif 'song_raw' in self.ds:
+        if 'song_raw' in self.ds:
             self.fs_song = self.ds.song_raw.attrs['sampling_rate_Hz']
-            self.nb_channels = self.ds.song_raw.shape[-1]
+            self.nb_channels = self.ds.song_raw.shape[1]
         else:
             self.fs_song = self.fs_other  # not sure this would work?
 
@@ -585,8 +620,8 @@ class PSV(MainWindow):
                                 checkable=True, checked=self.show_all_channels)
         self.add_keyed_menuitem(view_audio, "Auto-select loudest channel", partial(self.toggle, 'select_loudest_channel'), "Q",
                                 checkable=True, checked=self.select_loudest_channel)
-        self.add_keyed_menuitem(view_audio, "Select previous channel", self.set_next_channel, "Shift+Up")
-        self.add_keyed_menuitem(view_audio, "Select next channel", self.set_prev_channel, "Shift+Down")
+        self.add_keyed_menuitem(view_audio, "Select previous channel", self.set_next_channel, "Up")
+        self.add_keyed_menuitem(view_audio, "Select next channel", self.set_prev_channel, "Down")
         view_audio.addSeparator()
         self.add_keyed_menuitem(view_audio, "Show spectrogram", partial(self.toggle, 'show_spec'), "G",
                                 checkable=True, checked=self.show_spec)
@@ -630,9 +665,10 @@ class PSV(MainWindow):
         self.view_audio = view_audio
         self.event_items = []
         for ii in range(self.cb.count()):
-            self.cb.itemText(ii)
             # key = eval(f'"{ii}') if ii<10 else None
             key = str(ii) if ii<10 else None
+            key_label = f"({key})" if key is not None else ''
+            self.cb.setItemText(ii, f"{self.cb.itemText(ii)} {key_label}")
             menu_item =self.add_keyed_menuitem(self.view_audio,
                                                self.cb.itemText(ii),
                                                self.change_event_type,
@@ -1017,12 +1053,27 @@ class PSV(MainWindow):
         # this could be done by the view:
         f = scipy.interpolate.interp1d(region.xrange, self.trange,
                                        bounds_error=False, fill_value='extrapolate')
-        new_region = f(region.getRegion())
-        # replace segment in events
+
+
+        # find the moved segment in events
         this = self.event_times[self.current_event_name]
         event_idx = np.where(np.logical_and(this[:,0]==region.bounds[0],
                                             this[:,1]==region.bounds[1]))
+
+        # get the new region bounds
+        new_region = f(region.getRegion())
+
+        # fixes editing segments that are only partially displayed
+        # if the region bounds after editing match the bounds of the view,
+        # keep the old region bounds
+        if region.getRegion()[0] == region.xrange[0]:
+            new_region[0] = this[event_idx, 0]
+        if region.getRegion()[1] == region.xrange[1]:
+            new_region[1] = this[event_idx, 1]
+
+        # replace the move segment
         this[event_idx, :] = new_region
+
         logging.info(f'  Moved {self.current_event_name} from t=[{region.bounds[0]:1.4f}:{region.bounds[1]:1.4f}] to [{new_region[0]:1.4f}:{new_region[1]:1.4f}] seconds.')
         self.update_xy()
 
@@ -1225,22 +1276,20 @@ class PSV(MainWindow):
         dialog.show()
 
     def dss_predict(self, qt_keycode):
+        dialog = YamlDialog(yaml_file=package_dir + "/gui/forms/dss_predict.yaml",
+                                title='Predict labels using DeepSS')
+        dialog.show()
+        result = dialog.exec_()
 
-        def predict():
-            print('predict')
-            dialog.close()
+        if result == QtGui.QDialog.Accepted:
+            print('running inference in terminal window.')
             # load model and params
             # make data-gen from ds.song_raw
             # predict with progressbar
+            # add the raw probabilities to the ds so we can easily play around with the detection threshold and postprocessing parameters
             # post process probabilities and generate labels
             # add or update original (non-post processed) probabilities and final labels to ds.song_events
 
-        dialog = YamlDialog(yaml_file="src/xarray_behave/gui/forms/predict.yaml",
-                               title='Predict',
-                               main_callback=predict)
-        dialog.show()
-
-
     def dss_update_predictions(self, qt_keycode):
 
         def update_predictions():
@@ -1351,8 +1400,9 @@ class PSV(MainWindow):
             # add new ones (make this function)
             self.event_items = []
             for ii in range(self.cb.count()):
-                self.cb.itemText(ii)
-                key = eval(f'"{ii}"') if ii<10 else None
+                key = str(ii) if ii<10 else None
+                key_label = f"({key})" if key is not None else ''
+                self.cb.setItemText(ii, f"{self.cb.itemText(ii)} {key_label}")
                 menu_item =self.add_keyed_menuitem(self.view_audio,
                                                    self.cb.itemText(ii),
                                                    self.change_event_type,
@@ -1385,7 +1435,7 @@ def main(source: str = '', *, events_string: str = '', target_samplingrate: floa
         skip_dialog (bool): If True, skips the opening dialog and goes straight to opening the data.
     """
 
-    app = QtGui.QApplication([])
+    QtGui.QApplication([])
     mainwin = MainWindow()
     mainwin.show()
     if not len(source):
