@@ -106,12 +106,17 @@ class Draggable(pg.GraphItem):
         self.text = kwds.pop('text', [])
         self.data = kwds
         if 'pos' in self.data:
-            npts = self.data['pos'].shape[0]
-            self.data['data'] = np.empty(npts, dtype=[('index', int)])
-            self.data['data']['index'] = np.arange(npts)
+            if self.data['pos'] is None:
+                self.data = {}
+            else:
+                npts = self.data['pos'].shape[0]
+                self.data['data'] = np.empty(npts, dtype=[('index', int)])
+                self.data['data']['index'] = np.arange(npts)
         self.setTexts(self.text)
+
         if 'acceptDrags' in kwds:
             self.acceptDrags = kwds['acceptDrags']
+
         if 'focalFly' in kwds:
             self.focalFly = kwds['focalFly']
         else:
@@ -130,7 +135,7 @@ class Draggable(pg.GraphItem):
 
     def updateGraph(self):
         pg.GraphItem.setData(self, **self.data)
-        for i,item in enumerate(self.textItems):
+        for i, item in enumerate(self.textItems):
             item.setPos(*self.data['pos'][i])
 
 
@@ -138,7 +143,6 @@ class Draggable(pg.GraphItem):
         if ev.button() != QtCore.Qt.LeftButton or not self.acceptDrags:
             ev.ignore()
             return
-        # breakpoint()
 
         if ev.isStart():
             # We are already one step into the drag.
@@ -431,10 +435,16 @@ class MovieView(utils.FastImageWidget):
             if 'pose_positions_allo' in self.m.ds:
                 if self.m.show_poses:
                     frame = self.annotate_poses(frame)
+                    self.fly_poses.setVisible(True)
                 else:
-                    self.fly_poses.setData(adj=np.array((0, 2)))
+                    self.fly_poses.setData(pos=None)
+                    self.fly_poses.setVisible(False)
+
                 if self.m.show_dot:
                     frame = self.annotate_dot(frame)
+                else:
+                    self.fly_positions.setData(pos=None)  # this deletes the graph
+
                 if self.m.crop:
                     x_range, y_range = self.crop_frame(frame)
                 else:
@@ -463,12 +473,14 @@ class MovieView(utils.FastImageWidget):
                                                        this_fly,
                                                        self.m.thorax_index].astype(np.uintp)
             fly_pos = np.array(fly_pos)  # in case this is a dask.array
-            xx, yy = skimage.draw.circle_perimeter(fly_pos[0], fly_pos[1], self.m.circle_size, method='bresenham')
-            frame[xx, yy, :] = color
+            # only plot circle if fly is within the frame (also prevents overflow errors
+            # for tracking errors that lead to VERY large position values)
+            if fly_pos[0] <= frame.shape[0] and fly_pos[1] <= frame.shape[1]:
+                xx, yy = skimage.draw.circle_perimeter(fly_pos[0], fly_pos[1], self.m.circle_size, method='bresenham')
+                frame[xx, yy, :] = color
         return frame
 
     def annotate_poses(self, frame):
-        # TODO use (non-draggable) GraphItem here as well - could even plot skeleton
         poses = np.array(self.m.ds.pose_positions_allo.data[self.m.index_other, :, :])
         poses = poses.reshape(-1, 2)  # flatten
         self.fly_poses.setData(pos=poses[:,::-1],
