@@ -16,7 +16,7 @@ import xarray as xr
 import zarr
 import math
 from . import xarray_behave as xb
-from . import _ui_utils
+from . import event_utils
 from typing import Sequence
 
 
@@ -212,7 +212,11 @@ def infer_event_categories(data):
     """
     event_categories = []
     for evt in range(data.shape[1]):
-        dt = np.median(np.diff(np.where(data[:, evt])[0]))
+        if np.any(data[:, evt]):
+            dt = np.nanmedian(np.diff(np.where(data[:, evt])[0]))
+        else:
+            dt = 10  # fall back to events w/o annotations
+
         if dt > 1:
             event_categories.append('event')
         else:
@@ -284,10 +288,19 @@ def load_manual_annotation(filepath):
 
     if 'event_categories' not in manual_events_ds:
         event_categories_List = infer_event_categories(manual_events_ds.song_events.data)
+
+        # force these to be the correct types even if they are empty and
+        # the event_cat inference does not work
+        for cnt, event_type in enumerate(manual_events_ds.event_types.data):
+            if event_type in ['pulse_manual', 'vibration_manual', 'aggression_manual']:
+                event_categories_List[cnt] = 'event'
+            if event_type == 'sine_manual':
+                event_categories_List[cnt] = 'segment'
+
         manual_events_ds = manual_events_ds.assign_coords(
                                 {'event_categories': (('event_types'), event_categories_List)})
 
-    event_seconds = _ui_utils.detect_events(manual_events_ds)
+    event_seconds = event_utils.detect_events(manual_events_ds)
 
     event_categories = {}
     for typ, cat in zip(manual_events_ds.event_types.data, manual_events_ds.event_categories.data):
@@ -524,7 +537,8 @@ def load_times(filepath_timestamps, filepath_daq):
 
 
 def initialize_manual_song_events(ds: xr.Dataset, from_segmentation: bool = False, force_overwrite: bool = False,
-                                  new_manual_event_types = ['sine_manual', 'pulse_manual', 'vibration_manual', 'aggression_manual']) -> xr.Dataset:
+                                  new_manual_event_types = ['sine_manual', 'pulse_manual', 'vibration_manual', 'aggression_manual'],
+                                  new_manual_event_categories = ['segment', 'event', 'event', 'event']) -> xr.Dataset:
     """[summary]
 
     Args:
@@ -537,17 +551,16 @@ def initialize_manual_song_events(ds: xr.Dataset, from_segmentation: bool = Fals
         force_overwrite (bool, optional): Overwrite existing manual events.
                                           Defaults to False.
         new_manual_event_types = ['sine_manual', 'pulse_manual', 'vibration_manual', 'aggression_manual']
-
+        new_manual_event_categories = ['segment', 'event', 'event', 'event']
     Returns:
         xarray.Dataset: [description]
     """
-    # ????!!!! no!!
+
+    # only add new ones
     if 'song_events' in ds:
-        new_manual_event_types = [evt for evt in new_manual_event_types
+        new_manual_event_categories = [cat for evt, cat in zip(new_manual_event_types, new_manual_event_categories)
                                       if evt not in ds.song_events.event_types]
-    # else:
-    #     # set time axis at target_sampling_rate
-    #     ds['time'] = np.arange(ds.sampletime[0], ds.sampletime[-1], 1/ds.attrs['target_sampling_rate'])
+        new_manual_event_types = [evt for evt in new_manual_event_types if evt not in ds.song_events.event_types]
 
     song_events_manual = None
     if 'song_events' not in ds or new_manual_event_types:
@@ -558,6 +571,7 @@ def initialize_manual_song_events(ds: xr.Dataset, from_segmentation: bool = Fals
                                           dims=['time', 'event_types'],
                                           coords={'time': ds.time,
                                                   'event_types': new_manual_event_types,
+                                                  'event_categories': (('event_types'), new_manual_event_categories),
                                                   'nearest_frame': (('time'), ds.nearest_frame), },
                                           attrs={'description': 'Event times as boolean arrays.',
                                                  'sampling_rate_Hz': ds.attrs['target_sampling_rate_Hz'],
